@@ -99,6 +99,19 @@ module.exports = grammar({
     $.keyword_identifier,
   ],
 
+  reserved: {
+    global: _ => [
+      // https://docs.python.org/3/reference/lexical_analysis.html#keywords
+      'False', 'await', 'else', 'import', 'pass',
+      'None', 'break', 'except', 'in', 'raise',
+      'True', 'class', 'finally', 'is', 'return',
+      'and', 'continue', 'for', 'lambda', 'try',
+      'as', 'def', 'from', 'nonlocal', 'while',
+      'assert', 'del', 'global', 'not', 'with',
+      'async', 'elif', 'if', 'or', 'yield',
+    ],
+  },
+
   word: $ => $.identifier,
 
   rules: {
@@ -341,47 +354,25 @@ module.exports = grammar({
       'try',
       ':',
       field('body', $._suite),
-      choice(
-        seq(
-          repeat1($.except_clause),
-          optional($.else_clause),
-          optional($.finally_clause),
-        ),
-        seq(
-          repeat1($.except_group_clause),
-          optional($.else_clause),
-          optional($.finally_clause),
-        ),
-        $.finally_clause,
-      ),
+      repeat($.except_clause),
+      optional($.else_clause),
+      optional($.finally_clause),
     ),
 
     except_clause: $ => seq(
       'except',
-      optional(seq(
-        field('value', $.expression),
-        optional(seq(
-          choice('as', ','),
-          field('alias', $.expression),
-        )),
+      optional(token(prec(1, '*'))),
+      optional(choice(
+        seq(
+          field('value', $.expression),
+          optional(seq('as', field('alias', $.expression))),
+        ),
+        commaSep1(field('value', $.expression)),
       )),
       ':',
       $._suite,
     ),
 
-    except_group_clause: $ => seq(
-      'except*',
-      seq(
-        $.expression,
-        optional(seq(
-          'as',
-          $.expression,
-        )),
-      ),
-      ':',
-      $._suite,
-    ),
-
     finally_clause: $ => seq(
       'finally',
       ':',
